translate.storage._factory_classes

Package translate :: Package storage :: Module _factory_classes |
[hide private]
[frames] | no frames]

# Module _factory_classes

source code

Py2exe can't find stuff that we import dynamically, so we have this file just for the sake of the Windows installer to easily pick up all the stuff that we need and ensure they make it into the installer.

Imports: csvl10n, omegat, po, mo, qm, utx, wordfast, catkeys, qph, tbx, tmx, ts2, xliff, trados